# FormatEnum


## Enum

* `PDF` (value: `'pdf'`)

* `JPEG` (value: `'jpeg'`)

* `PNG` (value: `'png'`)

* `JPG` (value: `'jpg'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


